@@ -14,7 +14,7 @@
 #include <config.h>
 #endif 
 
-#include <ntqptrlist.h>
+#include <tqptrlist.h>
 
 #include <kbiffmonitor.h>
 #include <setupdlg.h>
@@ -22,8 +22,8 @@
 #include <kbiffurl.h>
 #include <kapp.h>
 
-#include <ntqlabel.h>
-#include <ntqtimer.h>
+#include <tqlabel.h>
+#include <tqtimer.h>
 
 #include <notify.h>
 #include <status.h>
