@@ -35,11 +35,11 @@
 #include <kbiffurl.h>
 #include <kdebug.h>
 
-#include <ntqapplication.h>
-#include <ntqstring.h>
-#include <ntqregexp.h>
-#include <ntqdir.h>
-#include <ntqdatetime.h>
+#include <tqapplication.h>
+#include <tqstring.h>
+#include <tqregexp.h>
+#include <tqdir.h>
+#include <tqdatetime.h>
 #include <ksimpleconfig.h>
 
 // Needed for CRAM-MD5 and APOP
