@@ -8,10 +8,10 @@
 #include "notify.h"
 #include "notify.moc"
 
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqpixmap.h>
-#include <ntqpushbutton.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqpixmap.h>
+#include <tqpushbutton.h>
 
 #include <kapp.h>
 #include <tdeglobal.h>
