@@ -8,25 +8,25 @@
 #include "setupdlg.h"
 #include "setupdlg.moc"
 
-#include <ntqgroupbox.h>
-#include <ntqfileinfo.h>
-#include <ntqlineedit.h>
-#include <ntqcheckbox.h>
-#include <ntqpushbutton.h>
-#include <ntqcombobox.h>
-#include <ntqheader.h>
-#include <ntqtabwidget.h>
+#include <tqgroupbox.h>
+#include <tqfileinfo.h>
+#include <tqlineedit.h>
+#include <tqcheckbox.h>
+#include <tqpushbutton.h>
+#include <tqcombobox.h>
+#include <tqheader.h>
+#include <tqtabwidget.h>
 
-#include <ntqpixmap.h>
-#include <ntqfont.h>
-#include <ntqlabel.h>
-#include <ntqstrlist.h>
-#include <ntqlayout.h>
-#include <ntqtooltip.h>
-#include <ntqdict.h>
-#include <ntqptrlist.h>
-#include <ntqwhatsthis.h>
-#include <ntqstylesheet.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
+#include <tqlabel.h>
+#include <tqstrlist.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqdict.h>
+#include <tqptrlist.h>
+#include <tqwhatsthis.h>
+#include <tqstylesheet.h>
 
 #include <kaudioplayer.h>
 #include <tdemessagebox.h>
